@@ -4,13 +4,14 @@ pub type Opcode = u8;
 
 pub const OP_TERMINATE: Opcode = 0;
 pub const OP_EVENT: Opcode = 1;
-// pub const OP_QUERY: Opcode = 2;
+pub const OP_QUERY: Opcode = 2;
 
 // Response opcode domain: [128, 256)
 
 // 2XX
 pub const OP_EVENT_RECEIVED: Opcode = 128;
-// pub const OP_QUERY_RESPONSE: Opcode = 129;
+pub const OP_QUERY_ACCEPTED: Opcode = 129;
+// pub const OP_QUERY_RESPONSE: Opcode = 130;
 
 // 4XX
 pub const OP_INVALID_FORMAT: Opcode = 130;
@@ -18,3 +19,10 @@ pub const OP_INVALID_FORMAT: Opcode = 130;
 // 5XX
 pub const OP_SERVER_AT_CAPACITY: Opcode = 131;
 pub const OP_INTERNAL_SERVER_ERROR: Opcode = 132;
+
+// Queries
+
+pub const INCLUDES_RANGE: Opcode = 0;
+pub const DOES_NOT_INCLUDE_RANGE: Opcode = 1;
+pub const INCLUDES_AGGR_WINDOW: Opcode = 0;
+pub const DOES_NOT_INCLUDE_AGGR_WINDOW: Opcode = 1;
